jQuery MultiSelect Widget Demo

## Refresh Method

Calling `refresh` allows you to re-build the multiselect menu from your original select. This is useful when the contents of the select box changes dynamically (through either AJAX, DOM manipulation, etc.) and you want the multiselect widget to reflect the changes.

    // once the "add" button is clicked below:
    $("select").multiselect('refresh');

### Add an item:

Type in the text of a new option tag to add dynamically.

Selected? Disabled?